@@ -1,23 +1,13 @@
 // ADImageView.h (this is -*- ObjC -*-)
 // 
-// \author: Bjrn Giesler <giesler@ira.uka.de>
+// Author: Bjrn Giesler <giesler@ira.uka.de>
 // 
 // Address View Framework for GNUstep
 // 
-// $Author: rmottola $
-// $Locker:  $
-// $Revision: 1.1 $
-// $Date: 2007/03/29 22:36:04 $
 
-#ifndef ADIMAGEVIEW_H
-#define ADIMAGEVIEW_H
+#import <Addresses/Addresses.h>
+#import <AppKit/AppKit.h>
 
-/* system includes */
-#include <Addresses/Addresses.h>
-#include <AppKit/AppKit.h>
-
-/* my includes */
-/* (none) */
 
 @interface ADImageView: NSImageView
 {
@@ -27,7 +17,7 @@
   ADPerson *_person;
   BOOL _mouseDownOnSelf, _mouseDragged;
 }
-- initWithFrame: (NSRect) frame;
+- (instancetype) initWithFrame: (NSRect) frame;
 - (void) setTarget: (id) target;
 - (void) setAction: (SEL) sel;
 - (void) mouseDown: (NSEvent*) event;
@@ -48,5 +38,3 @@
     willDragPerson: (ADPerson*) aPerson;
 - (NSImage*) draggingImage;
 @end
-
-#endif /* ADIMAGEVIEW_H */
